@@ -157,7 +157,8 @@ int io_iter(struct io_backend *b)
 	}
 	nfds = 0;
 
-	{
+
+	if (!b->reloading) {
 		struct nonblocking_fd *fd;
 
 		for(fd = b->files; fd; fd = fd->next) {
@@ -273,7 +274,7 @@ int io_iter(struct io_backend *b)
 			nco++;
 		}
 	}
-	if (!nfds && !nco) {
+	if (!nfds && !nco && !b->reloading) {
 		verbose("No listening fds and no pending events, exiting...\n");
 		return 0;
 	}
